@@ -189,7 +189,8 @@ class Element(ElementBase):
                 self._handle_driver_error(error)
             except InvalidSessionIdException as error:
                 self._handle_driver_error(error)
-            except StaleElementReferenceException:
+            except StaleElementReferenceException as error:
+                self.logger.error(f"{error}\ncontinue")
                 continue
             except ET.XPathEvalError as e:
                 self.logger.error(f"XPathEvalError: {e}")
@@ -435,7 +436,8 @@ class Element(ElementBase):
             except AttributeError as error:
                 self._handle_driver_error(error)
             except StaleElementReferenceException as error:
-                self._handle_driver_error(error)
+                self.logger.error(f"{error}\ncontinue")
+                continue
 
         raise GeneralElementException(
             msg=f"Failed to {inspect.currentframe().f_code.co_name} within {self.timeout=}",
@@ -476,7 +478,8 @@ class Element(ElementBase):
             except AttributeError as error:
                 self._handle_driver_error(error)
             except StaleElementReferenceException as error:
-                self._handle_driver_error(error)
+                self.logger.error(f"{error}\ncontinue")
+                continue
 
         raise GeneralElementException(
             msg=f"Failed to {inspect.currentframe().f_code.co_name} within {self.timeout=}",
@@ -513,7 +516,8 @@ class Element(ElementBase):
             except AttributeError as error:
                 self._handle_driver_error(error)
             except StaleElementReferenceException as error:
-                self._handle_driver_error(error)
+                self.logger.error(f"{error}\ncontinue")
+                continue
 
         raise GeneralElementException(
             msg=f"Failed to {inspect.currentframe().f_code.co_name}('{name}') within {self.timeout=}",
@@ -551,7 +555,8 @@ class Element(ElementBase):
             except AttributeError as error:
                 self._handle_driver_error(error)
             except StaleElementReferenceException as error:
-                self._handle_driver_error(error)
+                self.logger.error(f"{error}\ncontinue")
+                continue
 
         raise GeneralElementException(
             msg=f"Failed to {inspect.currentframe().f_code.co_name} within {self.timeout=}",
@@ -591,7 +596,8 @@ class Element(ElementBase):
             except AttributeError as error:
                 self._handle_driver_error(error)
             except StaleElementReferenceException as error:
-                self._handle_driver_error(error)
+                self.logger.error(f"{error}\ncontinue")
+                continue
 
         raise GeneralElementException(
             msg=f"Failed to {inspect.currentframe().f_code.co_name} within {self.timeout=}",
@@ -627,7 +633,8 @@ class Element(ElementBase):
             except AttributeError as error:
                 self._handle_driver_error(error)
             except StaleElementReferenceException as error:
-                self._handle_driver_error(error)
+                self.logger.error(f"{error}\ncontinue")
+                continue
 
         raise GeneralElementException(
             msg=f"Failed to {inspect.currentframe().f_code.co_name} within {self.timeout=}",
@@ -673,7 +680,8 @@ class Element(ElementBase):
             except AttributeError as error:
                 self._handle_driver_error(error)
             except StaleElementReferenceException as error:
-                self._handle_driver_error(error)
+                self.logger.error(f"{error}\ncontinue")
+                continue
         raise GeneralElementException(
             msg=f"Failed to {inspect.currentframe().f_code.co_name} within {self.timeout=}",
             stacktrace=traceback.format_stack()
@@ -709,7 +717,8 @@ class Element(ElementBase):
             except AttributeError as error:
                 self._handle_driver_error(error)
             except StaleElementReferenceException as error:
-                self._handle_driver_error(error)
+                self.logger.error(f"{error}\ncontinue")
+                continue
 
         raise GeneralElementException(
             msg=f"Failed to {inspect.currentframe().f_code.co_name} within {self.timeout=}",
@@ -744,7 +753,8 @@ class Element(ElementBase):
             except AttributeError as error:
                 self._handle_driver_error(error)
             except StaleElementReferenceException as error:
-                self._handle_driver_error(error)
+                self.logger.error(f"{error}\ncontinue")
+                continue
 
         raise GeneralElementException(
             msg=f"Failed to {inspect.currentframe().f_code.co_name} within {self.timeout=}",
@@ -775,7 +785,8 @@ class Element(ElementBase):
             except AttributeError as error:
                 self._handle_driver_error(error)
             except StaleElementReferenceException as error:
-                self._handle_driver_error(error)
+                self.logger.error(f"{error}\ncontinue")
+                continue
         raise GeneralElementException(
             msg=f"Failed to {inspect.currentframe().f_code.co_name} within {self.timeout=}",
             stacktrace=traceback.format_stack()
@@ -799,7 +810,8 @@ class Element(ElementBase):
             except AttributeError as error:
                 self._handle_driver_error(error)
             except StaleElementReferenceException as error:
-                self._handle_driver_error(error)
+                self.logger.error(f"{error}\ncontinue")
+                continue
         raise GeneralElementException(
             msg=f"Failed to {inspect.currentframe().f_code.co_name} within {self.timeout=}\n{duration}",
             stacktrace=traceback.format_stack()
@@ -861,7 +873,8 @@ class Element(ElementBase):
             except AttributeError as error:
                 self._handle_driver_error(error)
             except StaleElementReferenceException as error:
-                self._handle_driver_error(error)
+                self.logger.error(f"{error}\ncontinue")
+                continue
         # === Недостаточно данных для действия ===
         raise GeneralElementException(
             msg=f"Failed to {inspect.currentframe().f_code.co_name} within {self.timeout=}\n{locator=}\n{x=}\n{y=}\n{direction}\n{distance}\n",
@@ -889,7 +902,8 @@ class Element(ElementBase):
             except AttributeError as error:
                 self._handle_driver_error(error)
             except StaleElementReferenceException as error:
-                self._handle_driver_error(error)
+                self.logger.error(f"{error}\ncontinue")
+                continue
         raise GeneralElementException(
             msg=f"Failed to {inspect.currentframe().f_code.co_name} within {self.timeout=}\n{duration}",
             stacktrace=traceback.format_stack()
@@ -912,7 +926,8 @@ class Element(ElementBase):
             except AttributeError as error:
                 self._handle_driver_error(error)
             except StaleElementReferenceException as error:
-                self._handle_driver_error(error)
+                self.logger.error(f"{error}\ncontinue")
+                continue
         raise GeneralElementException(
             msg=f"Failed to {inspect.currentframe().f_code.co_name} within {self.timeout=}",
             stacktrace=traceback.format_stack()
@@ -938,7 +953,8 @@ class Element(ElementBase):
             except AttributeError as error:
                 self._handle_driver_error(error)
             except StaleElementReferenceException as error:
-                self._handle_driver_error(error)
+                self.logger.error(f"{error}\ncontinue")
+                continue
         raise GeneralElementException(
             msg=f"Failed to {inspect.currentframe().f_code.co_name} within {self.timeout=}",
             stacktrace=traceback.format_stack()
@@ -980,7 +996,8 @@ class Element(ElementBase):
             except AttributeError as error:
                 self._handle_driver_error(error)
             except StaleElementReferenceException as error:
-                self._handle_driver_error(error)
+                self.logger.error(f"{error}\ncontinue")
+                continue
         raise GeneralElementException(
             msg=f"Failed to {inspect.currentframe().f_code.co_name} within {self.timeout=}",
             stacktrace=traceback.format_stack()
@@ -1031,7 +1048,8 @@ class Element(ElementBase):
             except AttributeError as error:
                 self._handle_driver_error(error)
             except StaleElementReferenceException as error:
-                self._handle_driver_error(error)
+                self.logger.error(f"{error}\ncontinue")
+                continue
         raise GeneralElementException(
             msg=f"Failed to {inspect.currentframe().f_code.co_name} within {self.timeout=}",
             stacktrace=traceback.format_stack()
@@ -1048,9 +1066,12 @@ class Element(ElementBase):
                     return cast('Element', self)
                 self.scroll_down(percent=percent, speed=speed, return_bool=True)
             except (
-                    NoSuchDriverException, InvalidSessionIdException, AttributeError,
-                    StaleElementReferenceException) as error:
+                    NoSuchDriverException, InvalidSessionIdException, AttributeError
+                    ) as error:
                 self._handle_driver_error(error)
+            except StaleElementReferenceException as error:
+                self.logger.error(f"{error}\ncontinue")
+                continue
 
         raise GeneralElementException(
             msg=f"Failed to scroll to bottom within {self.timeout=}",
@@ -1068,9 +1089,11 @@ class Element(ElementBase):
                     return cast('Element', self)
                 self.scroll_up(percent=percent, speed=speed, return_bool=True)
             except (
-                    NoSuchDriverException, InvalidSessionIdException, AttributeError,
-                    StaleElementReferenceException) as error:
+                    NoSuchDriverException, InvalidSessionIdException, AttributeError) as error:
                 self._handle_driver_error(error)
+            except StaleElementReferenceException as error:
+                self.logger.error(f"{error}\ncontinue")
+                continue
 
         raise GeneralElementException(
             msg=f"Failed to scroll to top within {self.timeout=}",
@@ -1110,7 +1133,8 @@ class Element(ElementBase):
             except AttributeError as error:
                 self._handle_driver_error(error)
             except StaleElementReferenceException as error:
-                self._handle_driver_error(error)
+                self.logger.error(f"{error}\ncontinue")
+                continue
             except Exception as error:
                 # Some instability detected, information gathering required
                 self.logger.error(error)
@@ -1156,7 +1180,8 @@ class Element(ElementBase):
             except AttributeError as error:
                 self._handle_driver_error(error)
             except StaleElementReferenceException as error:
-                self._handle_driver_error(error)
+                self.logger.error(f"{error}\ncontinue")
+                continue
 
         raise GeneralElementException(
             msg=f"Failed to {inspect.currentframe().f_code.co_name} within {self.timeout=}",
@@ -1196,7 +1221,8 @@ class Element(ElementBase):
             except AttributeError as error:
                 self._handle_driver_error(error)
             except StaleElementReferenceException as error:
-                self._handle_driver_error(error)
+                self.logger.error(f"{error}\ncontinue")
+                continue
 
         raise GeneralElementException(
             msg=f"Failed to {inspect.currentframe().f_code.co_name} within {self.timeout=}",
@@ -1253,7 +1279,8 @@ class Element(ElementBase):
             except AttributeError as error:
                 self._handle_driver_error(error)
             except StaleElementReferenceException as error:
-                self._handle_driver_error(error)
+                self.logger.error(f"{error}\ncontinue")
+                continue
 
         raise GeneralElementException(
             msg=f"Failed to {inspect.currentframe().f_code.co_name} within {self.timeout=} {direction=} {percent=}",
@@ -1291,7 +1318,8 @@ class Element(ElementBase):
             except AttributeError as error:
                 self._handle_driver_error(error)
             except StaleElementReferenceException as error:
-                self._handle_driver_error(error)
+                self.logger.error(f"{error}\ncontinue")
+                continue
 
         raise GeneralElementException(
             msg=f"Failed to clear element within {self.timeout=}",
@@ -1329,7 +1357,8 @@ class Element(ElementBase):
             except AttributeError as error:
                 self._handle_driver_error(error)
             except StaleElementReferenceException as error:
-                self._handle_driver_error(error)
+                self.logger.error(f"{error}\ncontinue")
+                continue
 
         raise GeneralElementException(
             msg=f"Failed to get location_in_view within {self.timeout=}",
@@ -1374,7 +1403,8 @@ class Element(ElementBase):
             except AttributeError as error:
                 self._handle_driver_error(error)
             except StaleElementReferenceException as error:
-                self._handle_driver_error(error)
+                self.logger.error(f"{error}\ncontinue")
+                continue
 
         raise GeneralElementException(
             msg=f"Failed to set_value({value}) within {self.timeout=}",
@@ -1418,7 +1448,8 @@ class Element(ElementBase):
             except AttributeError as error:
                 self._handle_driver_error(error)
             except StaleElementReferenceException as error:
-                self._handle_driver_error(error)
+                self.logger.error(f"{error}\ncontinue")
+                continue
 
         raise GeneralElementException(
             msg=f"Failed to send_keys({text}) within {self.timeout=}",
@@ -1456,7 +1487,8 @@ class Element(ElementBase):
             except AttributeError as error:
                 self._handle_driver_error(error)
             except StaleElementReferenceException as error:
-                self._handle_driver_error(error)
+                self.logger.error(f"{error}\ncontinue")
+                continue
 
         raise GeneralElementException(
             msg=f"Failed to retrieve tag_name within {self.timeout=}",
@@ -1494,7 +1526,8 @@ class Element(ElementBase):
             except AttributeError as error:
                 self._handle_driver_error(error)
             except StaleElementReferenceException as error:
-                self._handle_driver_error(error)
+                self.logger.error(f"{error}\ncontinue")
+                continue
 
         raise GeneralElementException(
             msg=f"Failed to retrieve text within {self.timeout=}",
@@ -1532,7 +1565,8 @@ class Element(ElementBase):
             except AttributeError as error:
                 self._handle_driver_error(error)
             except StaleElementReferenceException as error:
-                self._handle_driver_error(error)
+                self.logger.error(f"{error}\ncontinue")
+                continue
 
         raise GeneralElementException(
             msg=f"Failed to submit element within {self.timeout=}",
@@ -1659,7 +1693,8 @@ class Element(ElementBase):
             except AttributeError as error:
                 self._handle_driver_error(error)
             except StaleElementReferenceException as error:
-                self._handle_driver_error(error)
+                self.logger.error(f"{error}\ncontinue")
+                continue
             except WebDriverException as error:
                 self._handle_driver_error(error)
 
@@ -1707,7 +1742,8 @@ class Element(ElementBase):
             except AttributeError as error:
                 self._handle_driver_error(error)
             except StaleElementReferenceException as error:
-                self._handle_driver_error(error)
+                self.logger.error(f"{error}\ncontinue")
+                continue
             except WebDriverException as error:
                 self._handle_driver_error(error)
 
@@ -1753,7 +1789,8 @@ class Element(ElementBase):
             except AttributeError as error:
                 self._handle_driver_error(error)
             except StaleElementReferenceException as error:
-                self._handle_driver_error(error)
+                self.logger.error(f"{error}\ncontinue")
+                continue
             except WebDriverException as error:
                 self._handle_driver_error(error)
 
@@ -1796,7 +1833,8 @@ class Element(ElementBase):
             except AttributeError as error:
                 self._handle_driver_error(error)
             except StaleElementReferenceException as error:
-                self._handle_driver_error(error)
+                self.logger.error(f"{error}\ncontinue")
+                continue
             except WebDriverException as error:
                 self._handle_driver_error(error)
 
@@ -1836,7 +1874,8 @@ class Element(ElementBase):
             except AttributeError as error:
                 self._handle_driver_error(error)
             except StaleElementReferenceException as error:
-                self._handle_driver_error(error)
+                self.logger.error(f"{error}\ncontinue")
+                continue
             except WebDriverException as error:
                 self._handle_driver_error(error)
 
@@ -1876,7 +1915,8 @@ class Element(ElementBase):
             except AttributeError as error:
                 self._handle_driver_error(error)
             except StaleElementReferenceException as error:
-                self._handle_driver_error(error)
+                self.logger.error(f"{error}\ncontinue")
+                continue
             except WebDriverException as error:
                 self._handle_driver_error(error)
 
@@ -1916,7 +1956,8 @@ class Element(ElementBase):
             except AttributeError as error:
                 self._handle_driver_error(error)
             except StaleElementReferenceException as error:
-                self._handle_driver_error(error)
+                self.logger.error(f"{error}\ncontinue")
+                continue
             except WebDriverException as error:
                 self._handle_driver_error(error)
 
@@ -1956,7 +1997,8 @@ class Element(ElementBase):
             except AttributeError as error:
                 self._handle_driver_error(error)
             except StaleElementReferenceException as error:
-                self._handle_driver_error(error)
+                self.logger.error(f"{error}\ncontinue")
+                continue
             except WebDriverException as error:
                 self._handle_driver_error(error)
 
@@ -1998,7 +2040,8 @@ class Element(ElementBase):
             except AttributeError as error:
                 self._handle_driver_error(error)
             except StaleElementReferenceException as error:
-                self._handle_driver_error(error)
+                self.logger.error(f"{error}\ncontinue")
+                continue
             except IOError as error:
                 self.logger.error(f"IOError while saving screenshot to {filename}: {error}")
                 return False
@@ -2041,7 +2084,8 @@ class Element(ElementBase):
                     child_class = child_element.get_attribute('class')
                     if parent_class != child_class:
                         return str(child_class)
-            except StaleElementReferenceException:
+            except StaleElementReferenceException as error:
+                self.logger.error(f"{error}\ncontinue")
                 continue
 
     def _get_xpath(self) -> Union[str, None]:
